Error

Enum Error 

pub enum Error {
    DecodeTlsSctListError,
    DecodeTlsSctError,
    DecodeVersionError,
    DecodeIntError,
    DecodeLogIdError,
    DecodeTimestampError,
    DecodeExtensionsError,
    DecodeDigitallySignedError,
    DecodeHashAlgoError,
    DecodeSignAlgoError,
}
Error returned when decoding an SCT list

Variants



DecodeTlsSctListError

Returned if the SCT list’s length from the prefix doesn’t match the byte slice length



DecodeTlsSctError

Returned if the SCT’s length from the prefix is greater than the byte slice length



DecodeVersionError

Returned if the decoded Version is invalid



DecodeIntError

Returned if not enough bytes are left in the byte slice to decode an integer



DecodeLogIdError

Returned if less than 32 bytes are left in the byte slice to decode a log id



DecodeTimestampError

Returned if timestamp can’t be decoded into a der::asn1::UtcTime or a der::asn1::GeneralizedTime



DecodeExtensionsError

Returned if the extenions’ length from the prefix is greater than the byte slice length



DecodeDigitallySignedError

Returned if the digitally signed struct’s length from the prefix is greater than the byte slice length



DecodeHashAlgoError

Returned if the decoded HashAlgo is invalid



DecodeSignAlgoError

Returned if the decoded SignatureAlgo is invalid