pub struct SctList(pub OctetString);Expand description
Signed certificate timestamps list
Tuple Fields
0: OctetStringTrait Implementations
Sourceimpl AsExtension for SctList
impl AsExtension for SctList
Sourceimpl<'a> AsMut<OctetString> for SctList
impl<'a> AsMut<OctetString> for SctList
Sourcefn as_mut(&mut self) -> &mut OctetString
fn as_mut(&mut self) -> &mut OctetString
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl<'a> AsRef<OctetString> for SctList
impl<'a> AsRef<OctetString> for SctList
Sourcefn as_ref(&self) -> &OctetString
fn as_ref(&self) -> &OctetString
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl AssociatedOid for SctList
impl AssociatedOid for SctList
Sourceconst OID: ObjectIdentifier = CT_PRECERT_SCTS
const OID: ObjectIdentifier = CT_PRECERT_SCTS
The OID associated with this type.
Sourceimpl<'a> DecodeValue<'a> for SctList
impl<'a> DecodeValue<'a> for SctList
Sourceimpl<'a> EncodeValue for SctList
impl<'a> EncodeValue for SctList
Sourceimpl<'a> From<OctetString> for SctList
impl<'a> From<OctetString> for SctList
Sourcefn from(value: OctetString) -> Self
fn from(value: OctetString) -> Self
Converts to this type from the input type.
Sourceimpl<'a> From<SctList> for OctetString
impl<'a> From<SctList> for OctetString